services

package
v0.0.0-...-dc8b010 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2025 License: MIT Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ClusterJoinListener

type ClusterJoinListener struct {
	// contains filtered or unexported fields
}

func NewClusterJoinListener

func NewClusterJoinListener(conn *nats.Conn, serf *SerfAgent, nodeId string, nodeIdStore domain.NodeIdStore) *ClusterJoinListener

func (*ClusterJoinListener) Listen

func (l *ClusterJoinListener) Listen()

type RegistrationService

type RegistrationService struct {
	// contains filtered or unexported fields
}

func NewRegistrationService

func NewRegistrationService(client *magnetarapi.RegistrationAsyncClient, nodeIdRepo domain.NodeIdStore) *RegistrationService

func (*RegistrationService) Register

func (rs *RegistrationService) Register(maxRetries int8, bindAddress string) error

func (*RegistrationService) Registered

func (rs *RegistrationService) Registered() bool

type SerfAgent

type SerfAgent struct {
	Wg sync.WaitGroup
	// contains filtered or unexported fields
}

SerfAgent payloadBacklog is needed only if the payload splitting option is used

func NewSerfAgent

func NewSerfAgent(cf *configs.Config, nc *nats.Conn, nodeId string, configs domain.ConfigStore) (*SerfAgent, error)

NewSerfAgent payloadBacklog is needed only if the payload splitting option is used

func (*SerfAgent) GetClusterMembers

func (s *SerfAgent) GetClusterMembers() []serf.Member

func (*SerfAgent) Join

func (s *SerfAgent) Join(joinAddress string) error

func (*SerfAgent) Leave

func (s *SerfAgent) Leave()

func (*SerfAgent) Listen

func (s *SerfAgent) Listen()

func (*SerfAgent) RunMock

func (s *SerfAgent) RunMock()

RunMock Test 1 First block used for no payload splitting Second block used for NATS Third block used for payload splitting

func (*SerfAgent) TriggerUserEvent

func (s *SerfAgent) TriggerUserEvent(name, payload string, coalesce bool) error

TriggerUserEvent is used for no payload splitting

Jump to