Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterJoinListener ¶
type ClusterJoinListener struct {
// contains filtered or unexported fields
}
func NewClusterJoinListener ¶
func NewClusterJoinListener(conn *nats.Conn, serf *SerfAgent, nodeId string, nodeIdStore domain.NodeIdStore) *ClusterJoinListener
func (*ClusterJoinListener) Listen ¶
func (l *ClusterJoinListener) Listen()
type RegistrationService ¶
type RegistrationService struct {
// contains filtered or unexported fields
}
func NewRegistrationService ¶
func NewRegistrationService(client *magnetarapi.RegistrationAsyncClient, nodeIdRepo domain.NodeIdStore) *RegistrationService
func (*RegistrationService) Register ¶
func (rs *RegistrationService) Register(maxRetries int8, bindAddress string) error
func (*RegistrationService) Registered ¶
func (rs *RegistrationService) Registered() bool
type SerfAgent ¶
SerfAgent payloadBacklog is needed only if the payload splitting option is used
func NewSerfAgent ¶
func NewSerfAgent(cf *configs.Config, nc *nats.Conn, nodeId string, configs domain.ConfigStore) (*SerfAgent, error)
NewSerfAgent payloadBacklog is needed only if the payload splitting option is used
func (*SerfAgent) GetClusterMembers ¶
Click to show internal directories.
Click to hide internal directories.